DEFINITIONS = {
    "anti_patterns": {
        "ambiguous_groups": {
            "filename": "ambiguous_groups.md",
            "title": "Incorrect GROUP BY usage",
            "type": "Ambiguous Groups"
        },
        "fear_of_the_unknown": {
            "filename": "fear_of_the_unknown.md",
            "title": "Incorrect NULL usage",
            "type": "Fear of the Unknown"
        },
        "implicit_columns": {
            "filename": "implicit_columns.md",
            "title": "Avoid usage of wildcard selector",
            "type": "Implicit Columns"
        },
        "poor_mans_search_engine": {
            "filename": "poor_mans_search_engine.md",
            "title": "Avoid pattern matching",
            "type": "Poor Man's Search Engine"
        },
        "random_selection": {
            "filename": "random_selection.md",
            "title": "Avoid ORDER BY RAND() usage",
            "type": "Random Selection"
        }
    }
}
